<div align="center">
  <img src="https://charlesfrye.github.io/img/panndas-logo.jpeg"><br>
</div>

-----------------

# `panndas`: neural networks in `pandas`
[![Tests](https://github.com/charlesfrye/panndas/workflows/Tests/badge.svg)](https://github.com/charlesfrye/panndas/actions?workflow=Tests)
[![Coverage](https://codecov.io/github/charlesfrye/panndas/coverage.svg?branch=main)](https://codecov.io/gh/charlesfrye/panndas)
[![Read the Docs](https://readthedocs.org/projects/panndas/badge/)](https://panndas.readthedocs.io/)
[![PyPI Latest Release](https://img.shields.io/pypi/v/panndas.svg)](https://pypi.org/project/panndas/)
[![License](https://img.shields.io/pypi/l/panndas.svg)](https://github.com/pandas-dev/pandas/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/panndas?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/panndas)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## What is it?

**Pandas** are bears endemic to China characterized by a bold black-and-white coat, a rotund body, and a [remarkable similarity](https://wp.technologyreview.com/wp-content/uploads/2019/05/adversarial-10.jpg) to [gibbons](https://www.memphiszoo.org/assets/2510/10_white_cheek_gibbon.jpg).

**`pandas`** is a Python package that provides fast, flexible, and expressive data
structures designed to make working with "relational" or "labeled" data both
easy and intuitive.

**`panndas`** is a neural network library built on top of `pandas` as a joke.

## Main Features
Here are just a few of the things that `panndas` does well:

  -

## Frequently asked questions

#### How do you pronounce "`panndas`"?

There are two accepted pronunciations: "pa-`None`-das" and "🖕".

### Why?

> > > We do this not because it is easy, but because it is hard.
> >
> > _Wayne Gretsky_
>
> _Michael Scott_

_Me_

## Contributing to `panndas` [![Open Source Helpers](https://www.codetriage.com/charlesfrye/panndas/badges/users.svg)](https://www.codetriage.com/charlesfrye/panndas)

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are unwelcome.

## License
[YOLO](http://swansonquotes.com/wp-content/uploads/s05-ep01-permits1-1000x500.jpg)
